#!/bin/sh

#Conf dir/file definition
PKG_NAME="cloudstation"
PKG_FOLDER="/var/packages/CloudStation"
PKG_DIR="$PKG_FOLDER/target"
CONF_DIR="${PKG_FOLDER}/etc"
SYS_DIR_NAME="@${PKG_NAME}"

CONF_PATH="${CONF_DIR}/setting.conf"
PID_PATH="/var/run/synosyncfolder.pid"

# daemons
SYNORELAYD_PATH="/usr/syno/sbin/synorelayd"
CLOUD_CONTROL="${PKG_DIR}/bin/cloud-control"
UPDATER_PATH="${PKG_DIR}/bin/updater-svr"


#Global variables
CSTN_ENABLE="0"
KEEP_HISTORY="onemonth"
KEEP_VER="10"
MAX_SIZE="256mb"
CSTN_PORT="6690"
CSTN_DBG_LEVEL=0

debug_msg() {
	#echo "CS: $1";
	if [ 2 -le $CSTN_DBG_LEVEL ]; then
		logger -p 0 "CS: [start.sh]: $1"
	fi
}

info_msg() {
	#echo "CS: $1";
	if [ 1 -le $CSTN_DBG_LEVEL ]; then
		logger -p 0 "CS: [start.sh]: $1"
	fi
}

err_msg() {
	if [ 0 -le $CSTN_DBG_LEVEL ]; then
		logger -p 0 "CS: [start.sh]: $1"
	fi
}

get_conf() {
	if [ -f "${CONF_PATH}" ]; then
	    	CSTN_ENABLE=`/bin/get_key_value ${CONF_PATH} cstn_enable`
		KEEP_HISTORY=`/bin/get_key_value ${CONF_PATH} keep_history`
		KEEP_VER=`/bin/get_key_value ${CONF_PATH} keep_ver`
		MAX_SIZE=`/bin/get_key_value ${CONF_PATH} max_size`
		CSTN_PORT=`/bin/get_key_value ${CONF_PATH} cstn_port`
	else
		err_msg "Cloud station setting config does not exist!";
		exit 1;
	fi
}

stop_daemon() {
	${CLOUD_CONTROL} service --stop
}

start_daemon() {
	# start updater
	${UPDATER_PATH} "$1" &
}

get_conf;

case $1 in
    start)
		USER_HOME_ENABLE=`/bin/get_key_value /etc/synoinfo.conf userHomeEnable`
		if [ "x${USER_HOME_ENABLE}" != "xyes" ]; then
			err_msg "CS: You must enable user home first!"
			exit 1;
		fi

		err_msg "Cloud station start..."

		#Check if server is enable
		if [ "1" == "${CSTN_ENABLE}" ]; then
			stop_daemon;
			start_daemon "$2";
		else
			exit 0;
		fi
		;;

    stop)
		err_msg "Cloud station stop..."
		stop_daemon
   		;;

    restart)
		debug_msg "Cloud station restart..."
		$0 stop;
		$0 start;
    	;;
    *)
		echo "Usage: $0 start|stop|restart"
    ;;
esac

